summaryrefslogtreecommitdiff
path: root/mysys/my_error.c
diff options
context:
space:
mode:
Diffstat (limited to 'mysys/my_error.c')
-rw-r--r--mysys/my_error.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/mysys/my_error.c b/mysys/my_error.c
index 33d79bbc5e6..9789de9d58a 100644
--- a/mysys/my_error.c
+++ b/mysys/my_error.c
@@ -68,10 +68,10 @@ int my_error(int nr,myf MyFlags, ...)
}
else
{
/* Skipp if max size is used (to be compatible with printf) */
while (my_isdigit(&my_charset_latin1, *tpos) || *tpos == '.' || *tpos == '-')
tpos++;
- if (*tpos == 'l') /* Skipp 'l' argument */
+ if (*tpos == 'l') /* Skip 'l' argument */
tpos++;
if (*tpos == 's') /* String parameter */
{
@@ -68,10 +68,10 @@ int my_error(int nr,myf MyFlags, ...)
else
{
- /* Skipp if max size is used (to be compatible with printf) */
+ /* Skip if max size is used (to be compatible with printf) */
while (my_isdigit(&my_charset_latin1, *tpos) || *tpos == '.' || *tpos == '-')
tpos++;